import { useStepContext } from "@/app/(clean)/signup/Context";
import { memo, useState } from "react";
import { IMaskInput } from 'react-imask';
import api from "@/lib/api";
import type { BaseSyntheticEvent } from "react";
import type { InputStatus } from '@/types/form';

type EmailStatus = InputStatus|'progress';

export default memo(function Step1(){
	const [step, setStep] = useStepContext();
	const [info_type, setInfoType] = useState<'individual'|'company'>('individual');
	const [first_name, setFirstName] = useState('');
	const [first_name_status, setFirstNameStatus] = useState<InputStatus>('info');
	const [last_name, setLastName] = useState('');
	const [last_name_status, setLastNameStatus] = useState<InputStatus>('info');
	const [company_name, setCompanyName] = useState('');
	const [company_name_status, setCompanyNameStatus] = useState<InputStatus>('info');
	const [email, setEmail] = useState('');
	const [email_status, setEmailStatus] = useState<EmailStatus>('info');

	function next(){
		let email_status: EmailStatus = 'progress';
		setEmailStatus('progress');
		const first_name_status = first_name ? 'success' : 'error';
		const last_name_status = last_name ? 'success' : 'error';
		const company_name_status = company_name ? 'success' : 'error';
		setFirstNameStatus(first_name_status);
		setLastNameStatus(last_name_status);
		if(info_type==='company') setCompanyNameStatus(company_name_status);

		const gotoNextStep = ()=>{
			if(first_name_status==='success' && last_name_status==='success' && email_status==='success' && (info_type==='individual' || (info_type==='company' && company_name_status==='success')) )
			setStep(2);
		}

		if(email){
			api.get(`/users/email_verifier?email=${email}`)
			.then(res=>{
				email_status = res.data ? 'success' : 'error';
				setEmailStatus(email_status);
				gotoNextStep();
			});
		}
		else {
			setEmailStatus('error');
			gotoNextStep();
		}
	}

	return (
		<div className="max-w-lg mx-auto mt-12">
			<h1 className="text-brand-black text-2xl font-bold leading-loose">Verified phone number</h1>
			<IMaskInput
				type='tel'
				mask={[
					{mask: ''},
					{mask: '000'},
					{mask: '(000) 000'},
					{mask: '(000) 000-0000'},
				]}
				unmask={true}
				disabled
				value='2398872938'
				className="input !input-bordered w-full h-[3.75rem] rounded-[0.3125rem] mt-2.5 px-5 py-[0.9375rem] text-[32px] font-bold cursor-not-allowed !text-brand-black disabled:bg-transparent"
				placeholder='Phone Number'
			/>
			<p className="text-brand-black/50 text-xs mt-[1.6875rem]">Your order status will be updated via this phone number.</p>
			<hr className="border border-[#0116314D] my-[1.125rem]" />
			<p className="text-brand-black text-2xl font-bold leading-loose">Personal Info</p>

			<div className="flex gap-x-10 mt-3">
				<label className="cursor-pointer flex items-center gap-x-3">
					<input type="checkbox" checked={info_type==='individual'} onChange={()=>{ setInfoType('individual'); }} className="checkbox checkbox-primary w-5 h-5" />
					<p>Individual</p>
				</label>
				<label className="cursor-pointer flex items-center gap-x-3">
					<input type="checkbox" checked={info_type==='company'} onChange={()=>{ setInfoType('company'); }} className="checkbox checkbox-primary w-5 h-5" />
					<p>Company</p>
				</label>
			</div>

			<div className="mt-[1.375rem] flex gap-x-5">
				<div>
					<div className="grid grid-cols-[1fr_auto] gap-x-2 justify-around items-center border border-base-content/20 rounded-[0.3125rem]">
						<label className="input-float">
							<input type="text" value={first_name} onInput={(event:BaseSyntheticEvent<InputEvent>)=>{setFirstName(event.target.value)}} placeholder="" className="!border-0" />
							<p>First Name</p>
						</label>
						<div className="w-6 h-6 me-4">
							{ first_name_status==='info' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaInfo.svg" alt="icon" loading='lazy' data-tooltip-id="tooltip" data-tooltip-class-name="!bg-info" data-tooltip-content='First name is required' /> }
							{ first_name_status==='success' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaSuccess.svg" alt="icon" loading='lazy' /> }
							{ first_name_status==='error' && <img src="https://ik.imagekit.io/choreless/v2/icons/MaterialSymbolsCancelRounded.svg" alt="icon" loading='lazy' /> }
						</div>
					</div>
					{ first_name_status==='error' && <p className="text-error">* First name is required</p> }
				</div>
				<div>
					<div className="grid grid-cols-[1fr_auto] gap-x-2 justify-around items-center border border-base-content/20 rounded-[0.3125rem]">
						<label className="input-float">
							<input type="text" value={last_name} onInput={(event:BaseSyntheticEvent<InputEvent>)=>{setLastName(event.target.value)}} placeholder="" className="!border-0" />
							<p>Last Name</p>
						</label>
						<div className="w-6 h-6 me-4">
							{ last_name_status==='info' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaInfo.svg" alt="icon" loading='lazy' data-tooltip-id="tooltip" data-tooltip-class-name="!bg-info" data-tooltip-content='Last name is required' /> }
							{ last_name_status==='success' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaSuccess.svg" alt="icon" loading='lazy' /> }
							{ last_name_status==='error' && <img src="https://ik.imagekit.io/choreless/v2/icons/MaterialSymbolsCancelRounded.svg" alt="icon" loading='lazy' /> }
						</div>
					</div>
					{ last_name_status==='error' && <p className="text-error">* Last name is required</p> }
				</div>
			</div>
			{
				info_type==='company' &&
				<div className="mt-5">
					<div className="grid grid-cols-[1fr_auto] gap-x-2 justify-around items-center border border-base-content/20 rounded-[0.3125rem]">
						<label className="input-float">
							<input type="text" value={company_name} onInput={(event:BaseSyntheticEvent<InputEvent>)=>{setCompanyName(event.target.value)}} placeholder="" className="!border-0" />
							<p>Company Name</p>
						</label>
						<div className="w-6 h-6 me-4">
							{ company_name_status==='info' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaInfo.svg" alt="icon" loading='lazy' data-tooltip-id="tooltip" data-tooltip-class-name="!bg-info" data-tooltip-content='Company name is required' /> }
							{ company_name_status==='success' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaSuccess.svg" alt="icon" loading='lazy' /> }
							{ company_name_status==='error' && <img src="https://ik.imagekit.io/choreless/v2/icons/MaterialSymbolsCancelRounded.svg" alt="icon" loading='lazy' /> }
						</div>
					</div>
					{ company_name_status==='error' && <p className="text-error">* Company name is required</p> }
				</div>
			}
			<div className="mt-5">
				<div className="grid grid-cols-[1fr_auto] gap-x-2 justify-around items-center border border-base-content/20 rounded-[0.3125rem]">
					<label className="input-float">
						<input type="text" placeholder="" className="!border-0" value={email} onInput={(event:BaseSyntheticEvent<InputEvent>)=>{setEmail(event.target.value); setEmailStatus('info')}} />
						<p>Email</p>
					</label>
					<div className="w-6 h-6 me-4">
						{ email_status==='info' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaInfo.svg" alt="icon" loading='lazy' data-tooltip-id="tooltip" data-tooltip-class-name="!bg-info" data-tooltip-content='Email is required' /> }
						{ email_status==='success' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaSuccess.svg" alt="icon" loading='lazy' /> }
						{ email_status==='error' && <img src="https://ik.imagekit.io/choreless/v2/icons/MaterialSymbolsCancelRounded.svg" alt="icon" loading='lazy' /> }
						{ email_status==='progress' && <span className="loading bg-primary"></span> }
					</div>
				</div>
				{ email_status==='error' && !email && <p className="text-error">* Email is required</p> }
				{ email_status==='error' && email && <p className="text-error">* Invalid Email</p> }
			</div>
			<label className="input-float mt-5">
				<input type="text" placeholder="" />
				<p>Referral / Promo Code</p>
			</label>

			<label className="cursor-pointer flex items-center gap-x-3 my-5">
				<input type="checkbox" className="checkbox checkbox-primary w-5 h-5" />
				<div className="text-[#303651] text-xs">I want to receive text updates about promos and specials.</div>
			</label>
			<button onClick={next} className="btn w-full h-[3.75rem] rounded-[0.3125rem] text-2xl px-5 py-[0.9375rem] text-white bg-brand-orange border-brand-orange hover:text-brand-orange hover:bg-transparent hover:border-brand-orange">Continue</button>

		</div>
	)
})
